# Основы

Сообщения Kohana - это понятные человеку строки, представленные в виде короткого слова или фразы, называемой "ключ". Сообщения извлекают с помощью метода [Kohana::message], который возвращает либо группу сообщений целиком, либо отдельное сообщение.

Например, когда пользователь не вошел в систему и пытается зайти на страницу, требующую аутентифицикации, должна быть отображена ошибка типа "Вы должны залогиниться для доступа к данной странице". Это сообщение может храниться в файле `auth` под ключом `must_login`:

    $message = Kohana::message('auth', 'must_login');

Сообщения не переводятся автоматически. Для осуществления перевода используйте [функции перевода](using.translation):

    $translated = __(Kohana::message('auth', 'must_login'));

[!!] В Kohana v2 система сообщений использовалась для перевода. Однако, рекомендуется использовать новую систему перевода вместо системы сообщений, так как она выведет понятный текст даже если перевод не найден.

## Файлы сообщений

Все файлы сообщений являются PHP-файлами, хранимыми в директории `messages/`, и возвращают ассоциативные массивы:

    <?php defined('SYSPATH') or die('No direct script access.');

    return array(
        'must_login' => 'Вы должны залогиниться для доступа к этой странице',
        'no_access'  => 'У Вас недостаточно прав для доступа к странице',
    );

Файлы сообщений похожи на [файлы настроек](using.configuration#config-files) - они тоже собираются вместе. Это означает, что все сообщения, хранимые в файлах с именем `auth`, будут объединены в один массив, так что нет необходимости дублировать все сообщения, если Вы создаете новый файл `auth`.
